@@ -47,6 +47,7 @@ from ..crud import (
     EVENT2TABLE,
     delete_one_user_topic_practice,
     fetch_last_page,
+    fetch_chapter_for_subchapter,
     fetch_course,
     fetch_course_practice,
     fetch_one_user_topic_practice,
@@ -291,7 +292,6 @@ async def updatelastpage(
         # last_page_url is going to be .../ns/books/published/course/chapter/subchapter.html
         # We will treat the second to last element as the chapter and the final element
         # minus the .html as the subchapter
-        # TODO: PreTeXt books will nothave this url format!
         parts = request_data.last_page_url.split("/")
         if len(parts) < 2:
             rslogger.error(f"Unparseable page: {request_data.last_page_url}")
@@ -299,8 +299,23 @@ async def updatelastpage(
                 status=status.HTTP_422_UNPROCESSABLE_ENTITY,
                 detail=f"Unparseable page: {request_data.last_page_url}",
             )
-        lpd["last_page_chapter"] = parts[-2]
-        lpd["last_page_subchapter"] = ".".join(parts[-1].split(".")[:-1])
+
+        subchapter = ".".join(parts[-1].split(".")[:-1])
+        # if it is a PreTeXt book then the subchapter is a unique id with the whole book
+        # we can look it up from the chapter and subchapter tables.
+        if request_data.is_ptx_book:
+            course_row = await fetch_course(user.course_name)
+            chapter = await fetch_chapter_for_subchapter(
+                subchapter, course_row.base_course
+            )
+            rslogger.debug(
+                f"Got Chapter {chapter} for {subchapter} in {course_row.base_course}"
+            )
+            lpd["last_page_chapter"] = chapter
+        else:
+            lpd["last_page_chapter"] = parts[-2]
+
+        lpd["last_page_subchapter"] = subchapter
         lpd["last_page_accessed_on"] = datetime.utcnow()
         lpd["user_id"] = request.state.user.id
 
@@ -372,10 +387,17 @@ async def add_flashcard(
 # _getCompletionStatus
 # --------------------
 @router.get("/getCompletionStatus")
-async def getCompletionStatus(request: Request, lastPageUrl: str):
+async def getCompletionStatus(request: Request, lastPageUrl: str, isPtxBook: bool):
     if request.state.user:
-        last_page_chapter = lastPageUrl.split("/")[-2]
         last_page_subchapter = ".".join(lastPageUrl.split("/")[-1].split(".")[:-1])
+        if isPtxBook:
+            rslogger.debug(f"completion status for PTX book {lastPageUrl}")
+            course_row = await fetch_course(request.state.user.course_name)
+            last_page_chapter = await fetch_chapter_for_subchapter(
+                last_page_subchapter, course_row.base_course
+            )
+        else:
+            last_page_chapter = lastPageUrl.split("/")[-2]
         result = await fetch_user_sub_chapter_progress(
             request.state.user, last_page_chapter, last_page_subchapter
         )
